@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageEN.h 2193 2006-12-09 01:26:55Z svn $
+ * $Id: MessageEN.h 2264 2006-12-14 14:25:43Z svn $
  *****************************************************************************/
 
 #ifndef MESSAGE_EN_H
@@ -44,6 +44,7 @@
 #define MESSAGE_DATA_DIR_NOT_FOUND          "MESSAGE_DATA_DIR_PATH_NOT_FOUND"
 #define MESSAGE_DIGEST_STATE_INVALID        "MESSAGE_DIGEST_STATE_INVALID"
 #define MESSAGE_DIR_OPEN_FAILED             "MESSAGE_DIR_OPEN_FAILED"
+#define MESSAGE_DOWNLOAD_PASS_MISMATCH      "MESSAGE_DOWNLOAD_PASS_MISMATCH"
 #define MESSAGE_DOWNLOAD_SESSION_LIMIT_EXCEEDED "MESSAGE_DOWNLOAD_SESSION_LIMIT_EXCEEDED"
 #define MESSAGE_ENVIRONMENT_LOCATION_DIR_EXIST "MESSAGE_ENVIRONMENT_LOCATION_DIR_EXIST"
 #define MESSAGE_FILE_COPY_FAILED            "MESSAGE_FILE_COPY_FAILED"
@@ -65,7 +66,7 @@
 #define MESSAGE_FILE_TRUNC_FAILED           "MESSAGE_FILE_TRUNC_FAILED"
 #define MESSAGE_FILE_WRITE_FAILED           "MESSAGE_FILE_WRITE_FAILED"
 #define MESSAGE_HANDLER_COMMAND_INVALID     "MESSAGE_HANDLER_COMMAND_INVALID"
-#define MESSAGE_HNDL_PATH_INFO_TOO_LONG     "MESSAGE_HNDL_PATH_INFO_TOO_LONG"
+#define MESSAGE_HANDLER_PATH_INFO_TOO_LONG  "MESSAGE_HANDLER_PATH_INFO_TOO_LONG"
 #define MESSAGE_ICONV_CONVERTER_NOT_FOUND   "MESSAGE_ICONV_CONVERTER_NOT_FOUND"
 #define MESSAGE_ICONV_ENCODING_INVALID      "MESSAGE_ICONV_ENCODING_INVALID"
 #define MESSAGE_LIST_ID_INVALID             "MESSAGE_LIST_ID_INVALID"
@@ -81,6 +82,7 @@
 #define MESSAGE_POST_FILE_DIGEST_EMPTY      "MESSAGE_POST_FILE_DIGEST_EMPTY"
 #define MESSAGE_POST_FILE_DIGEST_TOO_LONG   "MESSAGE_POST_FILE_DIGEST_TOO_LONG"
 #define MESSAGE_POST_FILE_EXT_EMPTY         "MESSAGE_POST_FILE_EXT_EMPTY"
+#define MESSAGE_POST_FILE_EXT_INVALID       "MESSAGE_POST_FILE_EXT_INVALID"
 #define MESSAGE_POST_FILE_EXT_TOO_LONG      "MESSAGE_POST_FILE_EXT_TOO_LONG"
 #define MESSAGE_POST_FILE_MIME_EMPTY        "MESSAGE_POST_FILE_MIME_EMPTY"
 #define MESSAGE_POST_FILE_MIME_TOO_LONG     "MESSAGE_POST_FILE_MIME_TOO_LONG"
