@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: PostFlowController.h 2308 2006-12-24 10:30:57Z svn $
  *****************************************************************************/
 
 #ifndef POST_FLOW_CONTROLLER_H
@@ -67,7 +67,8 @@ private:
 
     void poster_list_add(apr_sockaddr_t *ip_address);
     void poster_list_clean();
-    apr_time_t poster_list_is_contain(apr_sockaddr_t *ip_address) const;
+    bool poster_list_is_contain(apr_sockaddr_t *ip_address,
+                                apr_time_t time_limit) const;
 
     static const char *dump_poster(apr_pool_t *pool, poster_t *poster);
 
