@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.cpp 2291 2006-12-22 14:07:00Z svn $
+ * $Id: PostFlowController.cpp 2309 2006-12-24 10:48:50Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -34,7 +34,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2291 2006-12-22 14:07:00Z svn $");
+SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2309 2006-12-24 10:48:50Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -49,30 +49,16 @@ PostFlowController::PostFlowController(apr_size_t min_post_interval_sec)
 
 bool PostFlowController::can_post(apr_sockaddr_t *ip_address)
 {
-    apr_time_t last_post_time;
-    apr_time_t post_interval_time;
-    bool can_post;
+    apr_time_t time_limit;
 
     ReadLocker lock(&lock_);
 
     // MEMO: 短時間の間に異なる ARRAY_SIZE_OF(poster_list_) 個の IP ア
     // ドレスから投稿があった場合，制限に漏れが生じる．
 
-    last_post_time = poster_list_is_contain(ip_address);
+    time_limit = apr_time_now() - min_post_interval_time_;
 
-    if (last_post_time == 0) {
-        can_post = true;
-    } else {
-        post_interval_time = apr_time_now() - last_post_time;
-
-        if (post_interval_time > min_post_interval_time_) {
-            can_post = true;
-        } else {
-            can_post = false;
-        }
-    }
-
-    return can_post;
+    return poster_list_is_contain(ip_address, time_limit);
 }
 
 void PostFlowController::regist_post(apr_sockaddr_t *ip_address)
@@ -171,27 +157,31 @@ void PostFlowController::poster_list_clean()
     poster_tail_ = i;
 }
 
-apr_time_t PostFlowController::poster_list_is_contain(apr_sockaddr_t *ip_address) const
+bool PostFlowController::poster_list_is_contain(apr_sockaddr_t *ip_address,
+                                                apr_time_t time_limit) const
 {
     apr_size_t i;
 
     if (poster_top_ == poster_tail_) {
-        return 0;
+        return true;
     }
 
     i = poster_top_;
     do {
+        if (poster_list_[i].time < time_limit) {
+            return true;
+        }
         if (is_address_match(&(poster_list_[i].ip_address[0]),
                              poster_list_[i].ip_address_size,
                              get_address(ip_address),
                              get_address_size(ip_address))) {
-            return poster_list_[i].time;
+            return false;
         }
     } while ((i = (i == 0)
               ? (ARRAY_SIZE_OF(poster_list_)-1)
               : (i-1)) != poster_tail_);
 
-    return 0;
+    return true;
 }
 
 const char *PostFlowController::dump_poster(apr_pool_t *pool, poster_t *poster)
