@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 2175 2006-12-06 17:27:48Z svn $
+ * $Id: TemplateExecutor.cpp 2297 2006-12-24 03:13:15Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -38,8 +38,10 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
+using namespace std;
+
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2175 2006-12-06 17:27:48Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2297 2006-12-24 03:13:15Z svn $");
 #endif
 
 #ifdef DEBUG_TemplateExecutor
@@ -663,19 +665,19 @@ TemplateExecutor<W>::create_scalar()
 
 template<class W>
 TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(const char *str,
-                                                         apr_size_t length) throw()
+                                                         apr_size_t length)
 {
     writer_.write(str, length);
 }
 
 template<class W>
-TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(const char *str) throw()
+TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(const char *str)
 {
     writer_.write(str);
 }
 
 template<class W>
-TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(int i) throw()
+TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(int i)
 {
     writer_.write(i);
 }
@@ -685,7 +687,6 @@ TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(int i) throw()
  * テスト
  *****************************************************************************/
 #ifdef DEBUG_TemplateExecutor
-#include "TestRunner.h"
 #include "UploaderTemplate.h"
 #include "UploadItemList.h"
 #include "UploadItemListReader.h"
@@ -695,6 +696,8 @@ TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(int i) throw()
 #include "TemplateVariableCreator.h"
 #include "CGIResponseWriter.h"
 
+#include "TestRunner.h"
+
 typedef TemplateExecutor<CGIResponseWriter> TemplateExecutorImpl;
 
 static const apr_size_t ITEM_LIST_SIZE  = 10;
